body.frame {
	padding: 0;
	margin: 0;
	font-family: sans-serif;
	height: 100%;
}

.email-log-parts ul {
	padding: 0;
	margin: 0 0 0 1em;
	list-style: none;
}

.email-log-parts li {
	padding: 0;
	margin: 0;
	list-style-type: none;
	line-height: 1.4;
}

.email-log-parts ul .content-disposition-inline > a {
	opacity: .2;
	font-size: 80%;
}

#email_form .field-subject .readonly {
	font-weight: bold;
}

#alternatives_switch {
	list-style: none;
	padding: 0;
	margin: 0 0 8px 0;
	border: none;
}

#alternatives_switch:after {
	content: " ";
	display: block;
	clear: both;
	border: none;
}

#alternatives_switch li {
	padding: 0;
	margin: 0;
	display: inline;
}

#alternatives_switch li a, #alternative_open {
	float: left;
	line-height: 32px;
	vertical-align: middle;
	background: #79aec8;
	color: #ffffff;
	margin: 0;
	padding: 0 16px;
	text-decoration: none;
	border-right: 1px solid #a9ced8;
	outline: 0;
}

#alternatives_switch li a:hover, #alternative_open:hover {
	color: #ffffff !important;
}

#alternative_open {
	float: right;
	border-radius: 5px;
	display: none;
}

#alternatives_switch li:first-child a {
	border-top-left-radius: 5px;
	border-bottom-left-radius: 5px;
}

#alternatives_switch li:last-child a {
	border-top-right-radius: 5px;
	border-bottom-right-radius: 5px;
}

#alternatives_switch li a:hover {
	background: #609ab6;
}

#alternatives_switch li.active a {
	background: #417690;
}

pre.alternative, iframe.alternative {
	border: none;
	background: #f8f8f8;
	border: 1px solid #eeeeee;
	padding: 10px;
	margin: 0;
	width: 100%;
	height: 800px;
	box-sizing: border-box;
}

body.frame pre.alternative, body.frame iframe.alternative {
	height: 100%;
	position: absolute;
	border: none;
	background: white;
	color: black;
}

.app-django_email_log .field-get_subject a {
	font-weight: normal;
}

.app-django_email_log .field-get_subject a strong {
	font-weight: bold;
}

.app-django_email_log .field-get_subject .status {
	display: inline-block;
	content: '';
	margin-right: 1em;
	vertical-align: middle;
	width: 1em;
	height: 1em;
	border-radius: 0.5em;
	background: #888;
	box-shadow: inset 0px .5em .5em rgba(255, 255, 255, .5);
}

.app-django_email_log .field-get_subject .status.success {
	background-color: #11aa22;
}

.app-django_email_log .field-get_subject .status.fail {
	background-color: #ee1111;
}

.app-django_email_log .field-get_subject .status.received {
	background-color: #5555dd;
}
