{% extends "admin/change_list.html" %}

{% load static %}

{% block extrastyle %}
{{ block.super }}
<link rel="stylesheet" type="text/css" href="{% static "django_email_log/css/admin.css" %}" />
{% endblock %}
